<?php

/*
Plugin Name: Swipe
Plugin URI: http://www.swipehq.com/
Description: A payment plugin for PrestaShop
Version: 1.7
*/

if (!defined('_PS_VERSION_'))
    exit;

class Swipe extends PaymentModule {
	
	private $_html = "";
    private $_protocol;
	
    private $_error = false;
    private $_swipe_currencies = array("NZD","AUD","CAD","EUR","GBP","KRW","SGD","CNY","USD","ZAR","HKD","JPY");

	public $apiKey;
	public $merchantId;
	public $apiUrl;
	public $paymentPageUrl;
	
    const VERSION = 1.7;
	
	const MERCHANT_ID = 'SWIPE_MERCHANT_ID';
	const API_KEY = 'SWIPE_API_KEY';
	const API_URL = 'SWIPE_API_URL';
	const PAYMENT_PAGE_URL = 'SWIPE_PAYMENT_PAGE_URL';
        const TEST_MODE = 'SWIPE_TEST_MODE';

	protected static $configVaribleibles = array(
		self::MERCHANT_ID,
		self::API_KEY, 
		self::API_URL, 
		self::PAYMENT_PAGE_URL,
                self::TEST_MODE,
	);
	
	protected static $fields = array(
		self::MERCHANT_ID => 'Merchant ID',
		self::API_KEY => 'API Key',
		self::API_URL => 'API Url',
		self::PAYMENT_PAGE_URL => 'Payment Page Url',
                self::TEST_MODE => 'Enable Test Mode'
	);
    
    public function __construct() {
        $this->name = 'swipe';
        $this->tab = 'payments_gateways';
        $this->version = self::VERSION;
        $this->author = 'Optimizer';
        
        

        /* Ensure user has configured this plugin */

        if($this->isConfigured()){
        	$this->merchantId = Configuration::get(self::MERCHANT_ID);
        	$this->apiKey = Configuration::get(self::API_KEY);
        	$this->apiUrl = Configuration::get(self::API_URL);
        	$this->paymentPageUrl = Configuration::get(self::PAYMENT_PAGE_URL);
                $this->test_mode = Configuration::get(self::TEST_MODE);
        }else{
        	$this->warning = $this->l('You need to configure Swipe Checkout before you can take payments');
        	$this->_error = true;
        }
        parent::__construct();
        
        $this->_protocol = $this->context->link->protocol_link;

        $this->displayName = $this->l('Swipe Checkout');
        $this->description = $this->l('A module to make Credit Card payments using Swipe Checkout');

        /* Check a current is set for the Swipe Module */
        if (!count(Currency::checkPaymentCurrencies($this->id))) {
            $this->warning = $this->l('No currency set for this module');
            $this->_error = true;
        }

        /* Make sure the only currency set is a valid Swipe HQ currency */
        if($this->isConfigured()){
        	$acceptedCurrencies = $this->getAcceptedCurrencies();
	        foreach (Currency::checkPaymentCurrencies($this->id) as $curr_id) {
	            $curr = Currency::getCurrency($curr_id["id_currency"]);
	            if (!in_array($curr["iso_code"], $acceptedCurrencies)) {
	            	$this->warning = $this->l('Swipe does not support a currency your shop uses: '.$curr['iso_code'].'. Swipe supports: '.join(', ', $acceptedCurrencies));
	                $this->_error = true;
	            }
	        }
        }
    }
	
	    public function install() {
        if (!parent::install() || !$this->registerHook('payment')){
            return false;
        }
        $this->registerHook('header');
        
        $swipe_os = new OrderState();
        $swipe_os->name = array();
        foreach (Language::getLanguages() as $language)
        {
            $swipe_os->name[$language['id_lang']] = "Credit Card Accepted";
        }
        $swipe_os->module = "swipe";
        $swipe_os->color = "#005500";
        $swipe_os->unremovable = true;
        $swipe_os->invoice = true;
        $swipe_os->logable = true; 
        /* 
         * Have to set logable to true for swipe payment to be added when order is validated.
         * Prestashop broke this in v1.5.4.1 in classes/PaymentModule.php#298
         */
	
        $swipe_os->add();//Create a Custom Status
        Configuration::updateValue('SWIPE_OS', $swipe_os->id);
        return true;
    }

    public function uninstall() {
    	$deleteOk = true;
    	foreach(self::$configVaribleibles as $configVarible){
    		if(!Configuration::deleteByName($configVarible)) return false;
    	}
    	if(!parent::uninstall()) return false;
        $swipe_os = new OrderStateCore(Configuration::get("SWIPE_OS"));
        $swipe_os->delete();//Remove Custom Status
        Configuration::deleteByName('SWIPE_OS');
        return true;
    }



    public function hookPayment($params) {
        if ($this->_error == false) {
            $this->smarty->assign('this_path', $this->_path);
            if (version_compare(_PS_VERSION_, '1.6', '>=')){
                return $this->display(__FILE__, 'swipe_payment.tpl');
            }
            else{
                return $this->display(__FILE__, 'swipe_payment_old.tpl');
            }
        }
    }
    public function hookHeader($params){
        if (version_compare(_PS_VERSION_, '1.6', '>=')){
            $this->context->controller->addCSS(($this->_path).'swipe_custom.css', 'all');
        }
        else{
            //Tools::addCSS(($this->_path).'swipe_custom.css', 'all');
        }
    }

    //Configuration Section
    private function _postValidation() {
        if (Tools::isSubmit('btnSubmit')) {
        	foreach(self::$fields as $name => $label){
        		if (!Tools::getValue($name) || trim(Tools::getValue($name)) == '') {
        			$this->_postErrors[] = $this->l($label . ' is required');
        		}	
        	}
        }
    }
    
    protected function isConfigured(){
    	foreach(self::$configVaribleibles as $configVarible){
    		if(!Configuration::get($configVarible)){
    			return false;
    		}
    	}
    	return true;
    }
    
    protected function getAcceptedCurrencies(){
    	$url = $this->apiUrl.'fetchCurrencyCodes.php';
    	$params = array('merchant_id' => $this->merchantId,
    					'api_key' => $this->apiKey);
    	$ch = curl_init();
    	curl_setopt($ch, CURLOPT_URL, $url);
    	curl_setopt($ch, CURLOPT_POST, 1);
    	curl_setopt($ch, CURLOPT_POSTFIELDS, $params);
    	curl_setopt($ch, CURLOPT_RETURNTRANSFER, TRUE);
    	$result = json_decode(curl_exec($ch), true);
    	curl_close($ch);
    	
    	if($result['response_code'] == 200){
    		return (array) $result['data'];
    	}else{
    		return array();
    	}
    }

    private function _postProcess() {
        if (Tools::isSubmit('btnSubmit')) {
        	foreach(self::$configVaribleibles as $configVarible){
        		Configuration::updateValue($configVarible, Tools::getValue($configVarible));
        	}
        }
        $this->_html .= '<div class="conf confirm">Details Updated</div>';
    }

    private function _displayTop() {
        $this->_html .= '
            <div style="font-size: 12px; padding: 10px 20px; list-style: circle; line-height: 18px">
	            <p>
	            Swipe is a hub for integrated payment solutions that enables small businesses to transact smarter, better and cheaper than ever before.<br>
	            Swipe Checkout is designed for merchants who want to accept credit cards online, but don\'t want to pay the usual outrageous processing fees that accompany them.<br>
	            </p>
	            
	            <p>For more information, visit: <u><a href="http://www.swipehq.com">http://www.swipehq.com</a></u></p>
            </div>
        ';
        if(!$this->isConfigured()){
        	$this->_html .= '
            <div class="alert warning">
        		You need to configure Swipe Checkout before you can take payments
            </div>
	        ';
        }
    }

    private function _displayForm() {
        $this->_html .=
                '<form action="' . $_SERVER['REQUEST_URI'] . '" method="post">
                <fieldset>
                <legend>API Credentials</legend>
                		<p>
                		Enter the fields below with the details from your Merchant Account. Find these under <strong>Settings -> API Credentials </strong>
                		</p>
                        <table border="0" width="800" cellpadding="5" cellspacing="0" id="form" style="font-size: 12px">
                                <tr>
                                        <td width="130">Merchant ID</td>
                                        <td><input type="text" style="width:500px;" name="'.self::MERCHANT_ID.'" value="' . Tools::getValue(self::MERCHANT_ID, $this->merchantId) . '" ></td>
                                </tr>
                				<tr>
                                        <td width="130">API Key</td>
                                        <td><input type="text" style="width:500px;" name="'.self::API_KEY.'" value="' . Tools::getValue(self::API_KEY, $this->apiKey) . '" ></td>
                                </tr>
                				<tr>
                                        <td width="130">Payment Page Url</td>
                                        <td><input type="text" style="width:500px;" name="'.self::PAYMENT_PAGE_URL.'" value="' . Tools::getValue(self::PAYMENT_PAGE_URL, $this->paymentPageUrl) . '" ></td>
                                </tr>
                                <tr>
                                        <td width="130">API Url</td>
                                        <td><input type="text" style="width:500px;" name="'.self::API_URL.'" value="' . Tools::getValue(self::API_URL, $this->apiUrl) . '" ></td>
                                </tr>
                                
                                <tr>
                                        <td width="130">Enable Test Mode</td>
                                        <td>
                                            <select name="'.self::TEST_MODE.'">
                                                <option value="yes"'.(Tools::getValue(self::TEST_MODE, $this->test_mode)=="yes"?' selected':'').'>Yes</option>
                                                <option value="no"'.(Tools::getValue(self::TEST_MODE, $this->test_mode)=="no"?' selected':'').'>No</option>
                                            </select>
                                        </td>
                                </tr>

                                <tr>
                                        <td>&nbsp;</td>
                                        <td><input class="button" name="btnSubmit" value="Save" type="submit" /></td>
                                </tr>
                        </table>
                </fieldset>
        </form>
            <fieldset style="margin-top: 20px;">
            <legend>Swipe Payment Notifiers</legend>
					<p>
		            Once a customer makes a payment Swipe will send customers back to your site. In your Merchant Account, under <strong>Settings -> Payment Notifiers</strong> 
	        		update your notifiers to match the details below.
					</p>
                    <table border="0" width="800" cellpadding="5" cellspacing="0"  style="font-size: 12px">
                            <tr>
                                    <td width="130">Payment Redirect URL</td>
                                    <td><b>'.$this->_protocol . $this->context->shop->domain . $this->context->shop->physical_uri . 'index.php?fc=module&module=swipe&controller=success</b></td>
                            </tr>

                            <tr>
                                    <td width="130">Live Payment Notification URL</td>
                                    <td><b>'.$this->_protocol. $this->context->shop->domain . $this->context->shop->physical_uri . 'index.php?fc=module&module=swipe&controller=callback</b></td>
                            </tr>
                    </table>
            </fieldset>'.
            '<fieldset style="margin-top: 20px;">
            <legend>Test Configuration</legend>
					
                    <table border="0" width="800" cellpadding="5" cellspacing="0"  style="font-size: 12px">
                            <tr>
                                <td width="130"></td>
                                <td>
                                    <input type="button" id="check_config" name="check_results" value="Check Config" onclick="checkconfig()"></input>
                                </td>
                            </tr>
                            <tr>
                                <td width="130"></td>
                                <td>
                                    <div id="check_results" style="width:100%; height:100%"></div>
                                </td>
                            </tr>
                    </table>
            </fieldset>'.
            
            '<script>
                function checkconfig(){
                    jQuery("#check_results").html("<p style=\"font-size:50px\">Checking config, please wait...</p>");


                    var merchantId = jQuery("input[name=\'SWIPE_MERCHANT_ID\']").val();
                    var apiKey = jQuery("input[name=\'SWIPE_API_KEY\']").val();
                    var apiURL = jQuery("input[name=\'SWIPE_API_URL\']").val();
                    var paymentURL = jQuery("input[name=\'SWIPE_PAYMENT_PAGE_URL\']").val();

                    

                    var urlToLoad = "../modules/swipe/test-plugin.php?merchant_id="+merchantId+"&api_key="+apiKey+"&api_url="+apiURL+"&payment_page_url="+paymentURL;

                    jQuery("#check_results").load(urlToLoad);
                }
        </script>';
    }

    public function getContent() {
        $this->_html = '<img src="'.$this->_protocol.$this->context->shop->domain.$this->_path.'logo-big.png" style="margin-bottom:20px" />';
        if (Tools::isSubmit('btnSubmit')) {
            $this->_postValidation();
            if (!count($this->_postErrors))
                $this->_postProcess();
            else
                foreach ($this->_postErrors as $err)
                    $this->_html .= '<div class="alert error">' . $err . '</div>';
        }
        else
            $this->_html .= '<br />';

        $this->_displayTop();
        $this->_displayForm();

        return $this->_html;
    }
}
